*----------------------------------------------------------------------
* Program    : Five Card Draw
* Written by : Nicholas Loar
* Date       : 4/20/2012
* Excercise  : Final Project
* Description: This program will be a one player game in
*              which Five Card Draw will be played against 
*              the computer, one hand at a time.
*              Keyboard# 8 = Switch game modes during new hand prompt.
*----------------------------------------------------------------------

		ORG	$1000

DEBUGMODE 	EQU	0			; debug mode (0=normal mode, 1=test mode)

* Colors
AQUA		EQU	$00FFFF00
BLACK		EQU	$00000000
BLUE		EQU	$00FF0000
CARDBACK	EQU	$0000007E
CREAM		EQU	$008CE6F0
DARKBLUE	EQU	$007A0009
FUCHSIA		EQU	$00FF00FF
LTGRAY		EQU	$00C0C0C0
LIGHTGRAY	EQU	$00AEAEAE
GRAY		EQU	$00808080
DARKGRAY	EQU	$006A6A6A
TABLEGREEN	EQU	$00426E31
GREEN		EQU	$00008000
LIME		EQU	$0000FF00
MAROON		EQU	$00000080
NAVY		EQU	$00800000
OLIVE		EQU	$00008080
PURPLE		EQU	$00800080
RED		EQU	$000000FF
TEAL		EQU	$00808000
WHITE		EQU	$00FFFFFF
YELLOW		EQU	$0000FFFF
DEALERWINC	EQU	$0001019C
PLAYERWINC	EQU	$00600009
DRAWWINC	EQU	$00014204



********************** ELEMENT POSITIONS ******************************

* Discard Button
Discard_Button_Width	EQU		120
Discard_Button_Height	EQU		50
Discard_Button_Left	EQU		650
Discard_Button_Top	EQU		329
Discard_Button_Right	EQU		Discard_Button_Left+Discard_Button_Width
Discard_Button_Bottom	EQU		Discard_Button_Top+Discard_Button_Height

* New Hand Prompt
NewHand_Prompt_Top	EQU		197
NewHand_Prompt_Left	EQU		30
NewHand_Prompt_Width	EQU		153
NewHand_Prompt_Height	EQU		60

NewHand_Text_Top	EQU		NewHand_Prompt_Top+5
NewHand_Text_Left	EQU		NewHand_Prompt_Left+5

YesNo_Button_Height	EQU		20
YesNo_Button_Width	EQU		50
YesNo_Button_Gap	EQU		32
YesNo_Button_Top	EQU		NewHand_Prompt_Top+30
YesNo_Button_Bottom	EQU		YesNo_Button_Top+YesNo_Button_Height

Yes_Button_Left		EQU		NewHand_Prompt_Left+10
Yes_Button_Right	EQU		Yes_Button_Left+YesNo_Button_Width
Yes_Button_Text_Top	EQU		YesNo_Button_Top+3
Yes_Button_Text_Left	EQU		Yes_Button_Left+13

No_Button_Left		EQU		Yes_Button_Right+YesNo_Button_Gap
No_Button_Right		EQU		No_Button_Left+YesNo_Button_Width
No_Button_Text_Top	EQU		YesNo_Button_Top+3
No_Button_Text_Left	EQU		No_Button_Left+16

* Table Properties
Table_Width		EQU		800
Table_Height		EQU		600

Card_Width		EQU		80
Card_Height		EQU		112
Card_Left		EQU		180
Card_Gap		EQU		10
Dealer_Card_Top		EQU		40
Player_Card_Top		EQU		300
Player_Card_Bottom	EQU		Player_Card_Top+Card_Height

Player_Card1_Left	EQU		Card_Left
Player_Card1_Right	EQU		Player_Card1_Left+Card_Width
Player_Card2_Left	EQU		Player_Card1_Right+Card_Gap
Player_Card2_Right	EQU		Player_Card2_Left+Card_Width
Player_Card3_Left	EQU		Player_Card2_Right+Card_Gap
Player_Card3_Right	EQU		Player_Card3_Left+Card_Width
Player_Card4_Left	EQU		Player_Card3_Right+Card_Gap
Player_Card4_Right	EQU		Player_Card4_Left+Card_Width
Player_Card5_Left	EQU		Player_Card4_Right+Card_Gap
Player_Card5_Right	EQU		Player_Card5_Left+Card_Width



********************** MACROS *****************************************
* alphabetical order

* Add text to the back of cards
ADDCARDBACKTEXT MACRO				; \1 = card x, \2 = card y
	MOVEM.L	D0-D2/A1,-(SP)			; move registers to Stack
	LEA	cardbacktext,A1			; move the address of the card text into A1
	MOVE.W	\1,D1				; move x coordinate into D1.W
	ADD.W	#24,D1				; move the x coordinate right
	MOVE.W	\2,D2				; move y coordinate into D2.W
	ADD.W	#46,D2				; move the y coordinate down
	MOVE.B	#95,D0				; print null terminated string with x,y coord
	TRAP	#15				; run the task
	MOVEM.L	(SP)+,D0-D2/A1			; move registers back from Stack
	ENDM

* Delay for hundredths of a second in param 1
DELAY	MACRO
	move.b  #23,d0				; trap task 23
	move.l  #\1,d1				; delay amount
	trap    #15				; run the task
	ENDM

* Divide by 10
DIV10	MACRO					; \1 = result location
	DIVU	#10,\1				; number / 10
	EXT.L	\1				; convert lower word to long
	ENDM

* Draw a rectangle
DRAWRECT MACRO					; \1 = left,   \2 = top
						; \3 = width,  \4 = height
	MOVEM.L	D0-D4,-(SP)			; move registers to Stack
	MOVE.W	\1,D1				; move left into D1.W
	MOVE.W	\2,D2				; move top into D2.W
	MOVE.W	\1,D3				; move left into D3.W
	ADD.W	\3,D3				; add width to D3.W
	MOVE.W	\2,D4				; move top into D4.W
	ADD.W	\4,D4				; add height to D4.W
	MOVE.B	#87,D0				; i/o task to draw a rectangle
	TRAP	#15				; run the task
	MOVEM.L	(SP)+,D0-D4			; move registers back from Stack
	ENDM

* Draw text as a graphic
DRAWTEXT MACRO					; \1 = left,   \2 = top
						; \3 = null terminated string
	MOVEM.L	D0-D2/A1,-(SP)			; move registers to Stack
	MOVE.W	\1,D1				; move left coordinate into D1.W
	MOVE.W	\2,D2				; move top coordinate into D2.W
	LEA	\3,A1				; move the address of the string into A1
	MOVE.B	#95,D0				; print null terminated string with x,y coord
	TRAP	#15				; run the task
	MOVEM.L	(SP)+,D0-D2/A1			; move registers back from Stack
	ENDM

* Turn off echo
ECHO_OFF MACRO
	MOVEM.L	D0-D1,-(SP)			; move registers to Stack
	MOVE.B	#12,D0				; set echo in simulator
	MOVE.B	#0,D1				; 0 = turn off
	TRAP	#15				; run the task
	MOVEM.L	(SP)+,D0-D1			; move registers back from Stack
	ENDM

* Turn on echo
ECHO_ON MACRO
	MOVEM.L	D0-D1,-(SP)			; move registers to Stack
	MOVE.B	#12,D0				; set echo in simulator
	MOVE.B	#1,D1				; 0 = turn off
	TRAP	#15				; run the task
	MOVEM.L	(SP)+,D0-D1			; move registers back from Stack
	ENDM

* Get a number from the user
GETNUM	MACRO					; \1 = result location
	MOVE.B	#4,D0				; read number from keyboard into D1
	TRAP	#15				; run the task
	MOVE.W	D1,\1				; move the number into passed variable
	ENDM

* Extract suit from card
GETSUIT	MACRO					; \1 = index, \2 = result location
	MOVE.B	\1,D5				; move array index into D5
	MOVE.B	(A5,D5),\2			; move the card into result location
	MOD	\2				; extract the remainder (suit)
	ENDM

* Extract value from card
GETVAL	MACRO					; \1 = index, \2 = result location
	MOVE.B	\1,D5				; move array index into D5
	MOVE.B	(A5,D5),\2			; move the card into result location
	DIV10	\2				; extract the card value
	ENDM

* Get remainder
MOD	MACRO					; \1 = result location
	DIVU	#10,\1				; number / 10
	SWAP	\1				; swap upper and lower words to get remainder	
	EXT.L	\1				; convert lower word to long
	ENDM

* Print null terminated string
PRINT	MACRO					; \1 = variable
	LEA	\1,A1				; move the address of the string into A1
	MOVE.B	#14,D0				; print null terminated string
	TRAP	#15				; run the task
	ENDM

* Print number
PRINTN	MACRO					; \1 = variable
	MOVE.B	\1,D1				; move the number into D1
	MOVE.B	#3,D0				; display the number
	TRAP	#15				; run the task
	MOVE.B	#$20,D1				; move space ascii into D1
	MOVE.B	#6,D0				; display the character
	TRAP	#15
	ENDM

* Set i/o fill color
SETFILLCOLOR MACRO				; \1 = color value
	MOVEM.L	D0-D1,-(SP)			; move registers to Stack
	MOVE.L	\1,D1				; move the color into D1.L
	MOVE.B	#81,D0				; i/o task to set fill color
	TRAP	#15				; run the task
	MOVEM.L	(SP)+,D0-D1			; move registers back from Stack
	ENDM

* Set i/o pen color
SETPENCOLOR MACRO				; \1 = color value
	MOVEM.L	D0-D1,-(SP)			; move registers to Stack
	MOVE.L	\1,D1				; move the color into D1.L
	MOVE.B	#80,D0				; i/o task to set pen color
	TRAP	#15				; run the task
	MOVEM.L	(SP)+,D0-D1			; move registers back from Stack
	ENDM



********************** PROGRAM START **********************************

START
	* Initialize
	BSR	InitializeGame
	
	* Enter game loop
	BSR	GAME				; start the game
EXITGAME
	* Say goodbye to the player
	BSR	FinishGame
	
	STOP	#$2700				; stop the program

* Main game loop
* D7 = game position tracker
* D6 = loop counter
* D5 = return parameters from sub routines
* D2 = returned score of hand
* A5 = hand pointer
GAME
	BSR	ClearTable			; clear the table
	BSR	Shuffle				; shuffle the deck
	
	* Deal the cards
	if.b var_gameMode <eq> #1 then		; check for test mode
	  BSR	TestMode			;   branch to test mode
	  BSR	ClearTable			;   clear the table
	else					; else
	  BSR	DealTheCards			;   deal the cards
	endi					; end if
	
	* Draw the table
	BSR	DrawTable
	
	* Display player hand
	BSR	DisplayPlayerHand
	
	* Pause while the player selects which cards to discard
	MOVE.L #2,D7				; set game position
	if.b var_gameMode <eq> #0 then		; check for normal mode
	  BSR	PauseForDiscard
	endi
	MOVE.L #3,D7				; set game position
	
	* Manage the player hand (handle discard, check hand, display sorted)
	BSR	ManagePlayerHand
	
	* Allow dealer to discard
	if.b var_gameMode <eq> #0 then		; check for normal mode
	  BSR	DealerMove
	endi
	
	* Manage the dealer hand (handle discard, check hand, display sorted)
	BSR	ManageDealerHand
	
	* Determine the winner
	BSR	CheckScores			; get the winner
	BSR	UpdateWinner			; display the winner and update score
	
	* Prompt the user to play another hand
	MOVE.L	#4,D7				; set game position
	BSR	ManageNewHandPrompt
	
	* Loop if the player clicked yes
	if D4 <eq> #1 then			; if yes was clicked
	  BRA	GAME
	endi
	
	RTS



********************** SUB ROUTINES ***********************************
* alphabetical order

*Add text to a card
* D0 = string position counter / trap task
* D1 = card suit / left coordinate
* D2 = card value / top coordinate
* A1 = address of card string display
AddCardText
	MOVEM.L	D0-D2/A1,-(SP)			; move registers to Stack
	LEA	tempCardString,A1		; load the string into A2
	
	MOVE.W	tempCard,D1			; move card into D1
	DIV10	D1				; get value of card
	MOVE.B	#0,D0				; set the string position counter to 0
	if D1 <eq> #2 then
	  MOVE.B #$32,(A1,D0)			; 2
	endi
	if D1 <eq> #3 then
	  MOVE.B #$33,(A1,D0)			; 3
	endi
	if D1 <eq> #4 then
	  MOVE.B #$34,(A1,D0)			; 4
	endi
	if D1 <eq> #5 then
	  MOVE.B #$35,(A1,D0)			; 5
	endi
	if D1 <eq> #6 then
	  MOVE.B #$36,(A1,D0)			; 6
	endi
	if D1 <eq> #7 then
	  MOVE.B #$37,(A1,D0)			; 7
	endi
	if D1 <eq> #8 then
	  MOVE.B #$38,(A1,D0)			; 8
	endi
	if D1 <eq> #9 then
	  MOVE.B #$39,(A1,D0)			; 9
	endi
	if D1 <eq> #10 then
	  MOVE.B #$54,(A1,D0)			; Ten
	endi
	if D1 <eq> #11 then
	  MOVE.B #$4A,(A1,D0)			; Jack
	endi
	if D1 <eq> #12 then
	  MOVE.B #$51,(A1,D0)			; Queen
	endi
	if D1 <eq> #13 then
	  MOVE.B #$4B,(A1,D0)			; King
	endi
	if D1 <eq> #14 then
	  MOVE.B #$41,(A1,D0)			; Ace
	endi
						;***set the card suit
	MOVE.W	tempCard,D2			; move card into D2
	MOD	D2				; get suit of card
	MOVE.B	#1,D0				; set the string position counter to 1
	if D2 <eq> #1 then
	  SETFILLCOLOR #BLACK			; set the fill color
	  MOVE.B #$43,(A1,D0)			; Clubs
	endi
	if D2 <eq> #2 then
	  SETFILLCOLOR #RED			; set the fill color
	  MOVE.B #$44,(A1,D0)			; Diamonds
	endi
	if D2 <eq> #3 then
	  SETFILLCOLOR #RED			; set the fill color
	  MOVE.B #$48,(A1,D0)			; Hearts
	endi
	if D2 <eq> #4 then
	  SETFILLCOLOR #BLACK			; set the fill color
	  MOVE.B #$53,(A1,D0)			; Spades
	endi
						;***upper left display
	MOVE.W	RX,D1				; move x into D1.W
	ADD.W	#5,D1				; shift the x coordinate right
	MOVE.W	RY,D2				; move y into D2.W
	ADD.W	#5,D2				; shift the y coordinate down
	MOVE.B	#95,D0				; print null terminated string with x,y coord
	TRAP	#15				; run the task
						;***middle card text
	LEA	cardbacktext,A1			; move the string into A1
	ADD.W	#19,D1				; move the x coordinate right
	ADD.W	#41,D2				; move the y coordinate down
	TRAP	#15				; run the task
						;***bottom right display
	LEA	tempCardString,A1		; move the string into A1
	ADD.W	#36,D1				; move the x coordinate right
	ADD.W	#47,D2				; move the y coordinate down
	TRAP	#15				; run the task
	SETFILLCOLOR #WHITE			; set the fill color
	MOVEM.L	(SP)+,D0-D2/A1			; move registers back from Stack
	RTS

*Check the hand
* D2 = return score
* D3 = return hand
* D0 = temp variable
* D1 = temp variable
CheckHand
	CLR.L	D0				; clear D0 to use as temp variable
	CLR.L	D1				; clear D1 to use as temp variable
	CLR.L	D3				; clear D3 to use as return variable
	BSR	SortHand			; sort the hand
	MOVE.L	#0,D2				; set the score to 0
	BSR CheckStraightFlush			; check the hand for a winner
	if D2 <eq> #0 then
	  BSR CheckFourofaKind
	  if D2 <eq> #0 then
	    BSR	CheckFullHouse
	    if D2 <eq> #0 then
	      BSR CheckFlush
	      if D2 <eq> #0 then
	        BSR CheckStraight
	        if D2 <eq> #0 then
	          BSR CheckThreeofaKind
	          if D2 <eq> #0 then
	            BSR CheckTwoPair
	            if D2 <eq> #0 then
	              BSR CheckOnePair
	            endi
	          endi
	        endi
	      endi
	    endi
	  endi
	endi
	RTS

*Compare the scores to determine a winner
* D5 = winner (0 = dealer, 1 = player, 2 = draw)
CheckScores
	MOVE.B	playerScore,D0			; get player score
	MOVE.B	dealerScore,D1			; get dealer score
	MOVE.L	playerScoreCards,D3		; get player score cards
	MOVE.L	dealerScoreCards,D4		; get dealer score cards
	MOVE.L	#0,D5				; set dealer as default winner
	
	* Check card score for a clear winner
	if.b D0 <hi> D1 then			; if player score > dealer score
	  MOVE.B #1,D5				;   set player as the winner
	  BRA ReturnWinner			;   branch to return
	endi					; end if
	
	* Check if the card scores are equal
	if.b D0 <eq> D1 then			; if player score = dealer score
	  *flush and nothing
	  if.b D0 <eq> #0 or D0 <eq> #5 then	;   if player score is a 0 or 5
	    LEA	playerHand,A5			;     load the player hand into A5
	    LEA	dealerHand,A4			;     load the dealer hand into A4
	    for.w D6 = #0 to #4 do.s		;     loop through the 5 cards
	      MOVE.B (A5,D6),D0			;       move current player card into D0
	      DIV10 D0				;       get the card value
	      MOVE.B (A4,D6),D1			;       move current dealer card into D1
	      DIV10 D1				;       get the card value
	      if.b D0 <hi> D1 then		;       if player card > dealer card
	        MOVE.B #1,D5			;         set player as the winner
	        BRA ReturnWinner		;         branch to return
	      endi				;       end if
	      if.b D0 <lo> D1 then		;       if player card < dealer card
	        BRA ReturnWinner		;         branch to return
	      endi				;       end if
	    endf				;     end for
	    MOVE.B #2,D5			;     set player as the winner
	  *everything else
	  else					;   else
	    if.l D3 <eq> D4 then		;     if player score cards = dealer score cards
	      MOVE.B #2,D5			;       set draw as the winner
	      BRA ReturnWinner			;       branch to return
	    endi				;     end if
	    if.l D3 <hi> D4 then		;     if player score cards > dealer score cards
	      MOVE.B #1,D5			;       set player as the winner
	    endi				;     end if
	  endi					;   end if
	endi					; end if
ReturnWinner
	RTS

*Clear the graphical discard buttons
ClearDiscardButtons
	SETPENCOLOR  #TABLEGREEN		; set pen color
	SETFILLCOLOR #TABLEGREEN		; set fill color
	DRAWRECT #Discard_Button_Left,#Discard_Button_Top,#Discard_Button_Width,#Discard_Button_Height
	DRAWRECT #Card_Left,#(Player_Card_Bottom+1),#((Card_Width*5)+(Card_Gap*4)),#50
	SETPENCOLOR  #BLACK			; set pen color
	SETFILLCOLOR #WHITE			; set fill color
	RTS

*Clear the table
* D0 = task holder
* D1 = information for task
ClearTable
	MOVE.B	#11,D0				; clear the screen
	MOVE.W	#$FF00,D1
	TRAP	#15				; run the task
	SETPENCOLOR  #WHITE			; set pen color
	SETFILLCOLOR #BLACK			; set fill color
	MOVE.B	#0,discardCount			; reset discard count
	LEA	discardArray,A3			; load discard array into A3
	for.w D6 = #0 to #5 do.s		; loop 5 times
	  MOVE.B #0,(A3,D6)			;   reset the discard array
	endf					; end if
	CLR.L	D0				; clear the registers
	CLR.L	D1
	CLR.L	D2
	CLR.L	D3
	CLR.L	D4
	CLR.L	D5
	CLR.L	D6
	MOVE.L	#1,D7				; reset game position
	RTS

*Deal one card
* A6 = deck of cards pointer
* D1 = random number
* D5 = return card
* D4 = deck array limit
* D3 = deck array limit - 1
Deal
	CLR.L	D3				; clear D3
	CLR.L	D1				; clear D1
	BSR	GetRandomNumber			; get a random number
	LEA	deck,A6				; load the deck into A6
	MOVE.B	(A6,D1),D5			; move selected card value into D5
	
	MOVE.B	D4,D3				; get the array limit
	SUB.B	#1,D3				; subtract 1 from limit to get high element
	MOVE.B	(A6,D3),(A6,D1)			; move the last card to the selected spot
	MOVE.B	D5,(A6,D3)			; move the selected card to the end of the deck
	SUB.B	#1,D4				; subtract 1 from deck limit
	RTS

*Dealer decides what to play
DealerMove
	*determine which cards to discard
	LEA	dealerHand,A5			; load the dealer hand into A5
	LEA	discardArray,A3			; load discard array into A3
	BSR	CheckHand			; check the dealers hand (returns in D2)
	if.b D2 <ls> #3 then			; check for 3k, 2p, 1p, or nothing
	  *three of a kind
	  if.b D2 <eq> #3 then			;   check for 3k
	    GETVAL #0,D0			;     get value of card
	    GETVAL #2,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      MOVE.B #3,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #4,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      ADD.B  #2,discardCount		;       set discard count
	      BRA DealerFinishMove		;       branch to finish move
	    endi				;     end if
	    GETVAL #1,D0			;     get value of card
	    GETVAL #3,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      MOVE.B #0,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #4,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      ADD.B  #2,discardCount		;       set discard count
	      BRA DealerFinishMove		;       branch to finish move
	    endi				;     end if
	    GETVAL #2,D0			;     get value of card
	    GETVAL #4,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      MOVE.B #0,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #1,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      ADD.B  #2,discardCount		;       set discard count
	      BRA DealerFinishMove		;       branch to finish move
	    endi				;     end if
	  endi					;   end if
	  
	  *two pair
	  if.b D2 <eq> #2 then			;   check for 2p
	    GETVAL #0,D0			;     get value of card
	    GETVAL #1,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      GETVAL #2,D0			;       get value of card
	      GETVAL #3,D1			;       get value of card
	      if D0 <eq> D1 then		;       check if they are equal
	        MOVE.B #4,D1			;         discard array index
	        MOVE.B #1,(A3,D1)		;         select the card
	        ADD.B  #1,discardCount		;         set discard count
	        BRA DealerFinishMove		;         branch to finish move
	      endi				;       end if
	    endi				;     end if
	    GETVAL #0,D0			;     get value of card
	    GETVAL #1,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      GETVAL #3,D0			;       get value of card
	      GETVAL #4,D1			;       get value of card
	      if D0 <eq> D1 then		;       check if they are equal
	        MOVE.B #2,D1			;         discard array index
	        MOVE.B #1,(A3,D1)		;         select the card
	        ADD.B  #1,discardCount		;         set discard count
	        BRA DealerFinishMove		;         branch to finish move
	      endi				;       end if
	    endi				;     end if
	    GETVAL #1,D0			;     get value of card
	    GETVAL #2,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      GETVAL #3,D0			;       get value of card
	      GETVAL #4,D1			;       get value of card
	      if D0 <eq> D1 then		;       check if they are equal
	        MOVE.B #0,D1			;         discard array index
	        MOVE.B #1,(A3,D1)		;         select the card
	        ADD.B  #1,discardCount		;         set discard count
	        BRA DealerFinishMove		;         branch to finish move
	      endi				;       end if
	    endi				;     end if
	  endi					;   end if
	  
	  *one pair
	  if.b D2 <eq> #1 then			;   check for 1p
	    GETVAL #0,D0			;     get value of card
	    GETVAL #1,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      MOVE.B #2,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #3,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #4,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      ADD.B  #3,discardCount		;       set discard count
	      BRA DealerFinishMove		;       branch to finish move
	    endi				;     end if
	    GETVAL #1,D0			;     get value of card
	    GETVAL #2,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      MOVE.B #0,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #3,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #4,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      ADD.B  #3,discardCount		;       set discard count
	      BRA DealerFinishMove		;       branch to finish move
	    endi				;     end if
	    GETVAL #2,D0			;     get value of card
	    GETVAL #3,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      MOVE.B #0,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #1,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #4,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      ADD.B  #3,discardCount		;       set discard count
	      BRA DealerFinishMove		;       branch to finish move
	    endi				;     end if
	    GETVAL #3,D0			;     get value of card
	    GETVAL #4,D1			;     get value of card
	    if D0 <eq> D1 then			;     check if they are equal
	      MOVE.B #0,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #1,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      MOVE.B #2,D1			;       discard array index
	      MOVE.B #1,(A3,D1)			;       select the card
	      ADD.B  #3,discardCount		;       set discard count
	      BRA DealerFinishMove		;       branch to finish move
	    endi				;     end if
	  endi					;   end if
	  
	  *nothing
	  MOVE.B #2,D1				;   discard array index
	  MOVE.B #1,(A3,D1)			;   select the card
	  MOVE.B #3,D1				;   discard array index
	  MOVE.B #1,(A3,D1)			;   select the card
	  MOVE.B #4,D1				;   discard array index
	  MOVE.B #1,(A3,D1)			;   select the card
	  ADD.B  #3,discardCount		;   set discard count
	endi					; end if
DealerFinishMove
	*display number of cards discarded
	SETPENCOLOR	#LTGRAY			; set pen color
	SETFILLCOLOR	#DEALERWINC		; set fill color
	MOVE.B		#18,D0			; move 18 into D0
	MOVE.B		discardCount,D1		; move discard count into D1
	ADD.B		#$30,D1			; convert number to hex
	LEA		var_dealerSwapText,A4	; load player swap text into A5
	MOVE.B		D1,(A4,D0)		; move the count into the string
	DRAWRECT 	#(Table_Width/2-83),#(Dealer_Card_Top-25),#166,#20
	DRAWTEXT 	#(Table_Width/2-75),#(Dealer_Card_Top-22),var_dealerSwapText
	SETPENCOLOR	#BLACK			; set pen color
	SETFILLCOLOR	#WHITE			; set fill color
	
	*deal new cards
	for.w D6 = #0 to #4 do.s		; loop 5 times
	  if.b (A3,D6) <eq> #1 then		;   if card was selected
	    BSR		Deal			;     deal a new card
	    MOVE.B	D5,(A5,D6)		;     move the card into the dealers hand
	  endi					;   end if
	endf					; end for
	RTS

*Deal the cards to both the player and the dealer
DealTheCards
	  for.w D6 = #0 to #4 do.s		;   deal five cards to both player and dealer
	    BSR		Deal			;     deal a new card
	    LEA		playerHand,A5		;     load the player hand into A5
	    MOVE.B	D5,(A5,D6)		;     move the card into the players hand
	    BSR		Deal			;     deal a new card
	    LEA		dealerHand,A5		;     load the dealer hand into A5
	    MOVE.B	D5,(A5,D6)		;     move the card into the dealers hand
	  endf					;   end for
	  RTS

*Display the players hand
DisplayPlayerHand
	CLR.L	D0				; clear D0 to use as temp variable
	CLR.L	D1				; clear D1 to use as temp variable
	CLR.L	D3				; clear D3 to use as return variable
	LEA	playerHand,A5			; load the player hand into A5
	BSR	SortHand			; sort the hand
	MOVE.W	#Player_Card_Top,RY		; set Y of cards
	SETPENCOLOR  #BLACK			; set pen color
	SETFILLCOLOR #WHITE			; set fill color
	BSR	PrintHandGfx			; print the hand graphics
	RTS

*Draw the selected card highlight
DrawHighlight
	if.w D6 <eq> #0 then
	  DRAWRECT #(Player_Card1_Left+10),#(Player_Card_Bottom+1),#(Card_Width-20),#7
	endi
	if.w D6 <eq> #1 then
	  DRAWRECT #(Player_Card2_Left+10),#(Player_Card_Bottom+1),#(Card_Width-20),#7
	endi
	if.w D6 <eq> #2 then
	  DRAWRECT #(Player_Card3_Left+10),#(Player_Card_Bottom+1),#(Card_Width-20),#7
	endi
	if.w D6 <eq> #3 then
	  DRAWRECT #(Player_Card4_Left+10),#(Player_Card_Bottom+1),#(Card_Width-20),#7
	endi
	if.w D6 <eq> #4 then
	  DRAWRECT #(Player_Card5_Left+10),#(Player_Card_Bottom+1),#(Card_Width-20),#7
	endi
	RTS

*Display all elements on the table
DrawTable
	* Set the table color
	SETPENCOLOR  #TABLEGREEN		; set pen color
	SETFILLCOLOR #TABLEGREEN		; set fill color
	MOVE.W	#0,RX				; set X value
	MOVE.W	#0,RY				; set Y value
	MOVE.W	#Table_Width,RW			; set width
	MOVE.W	#Table_Height,RH		; set height
	DRAWRECT RX,RY,RW,RH			; draw table
	
	* Draw test mode text
	SETPENCOLOR  #CREAM			; set pen color
	SETFILLCOLOR #DRAWWINC			; set fill color
	if.b var_gameMode <eq> #1 then		; check for test mode
	  PRINT	var_testModeText		;   print test mode
	endi					; end if
	
	* Draw status rectangle
	SETPENCOLOR  #CREAM			; set pen color
	SETFILLCOLOR #CREAM			; set fill color
	MOVE.W	#220,RX				; set X value
	MOVE.W	#480,RY				; set Y value
	MOVE.W	#360,RW				; set width
	MOVE.W	#120,RH				; set height
	DRAWRECT RX,RY,RW,RH			; draw status rectangle
	
	* Draw decorations
	* left cards
	SETPENCOLOR  #BLACK			; set pen color
	SETFILLCOLOR #WHITE			; set fill color
	MOVE.W	#0,RX				; set X value
	MOVE.W	#522,RY				; set Y value
	MOVE.W	#80,RW				; set width
	MOVE.W	#112,RH				; set height
	MOVE.W	#32,tempCard			; set card number
	for.w D6 = #1 to #5 do.s		; loop 5 times
	  DRAWRECT RX,RY,RW,RH			;   draw decorative card
	  BSR AddCardText			;   display card text
	  ADD.W #38,RX				;   set X value
	  SUB.W #8,RY				;   set Y value
	  ADD.W #10,tempCard			;   create next decorative card
	endf					; end loop
	
	* right cards
	MOVE.W	#720,RX				; set X value
	MOVE.W	#522,RY				; set Y value
	MOVE.W	#133,tempCard			; set card number
	DRAWRECT RX,RY,RW,RH			; draw decorative card
	BSR AddCardText				; display card text
	SUB.W #38,RX				; set X value
	SUB.W #8,RY				; set Y of cards
	MOVE.W	#141,tempCard			; set card number
	for.w D6 = #1 to #4 do.s		; loop 4 times
	  DRAWRECT RX,RY,RW,RH			;   draw decorative card
	  BSR AddCardText			;   display card text
	  SUB.W #38,RX				;   set X value
	  SUB.W #8,RY				;   set Y of cards
	  ADD.W #1,tempCard			;   create next decorative card
	endf					; end loop
	
	* deck
	SETPENCOLOR  #LIGHTGRAY			; set pen color
	SETFILLCOLOR #CARDBACK			; set fill color
	MOVE.W	#700,RX				; set X value
	MOVE.W	#160,RY				; set Y value
	for.w D6 = #1 to #4 do.s		; loop 4 times
	  DRAWRECT RX,RY,RW,RH			;   draw deck layer
	  SUB.W #2,RX				;   set X value
	endf					; end loop
	SUB.W	#10,RX				; set X value
	SUB.W	#10,RY				; set Y value
	DRAWRECT RX,RY,RW,RH			; draw top card on deck
	ADDCARDBACKTEXT RX,RY			; display card back text
	
	* Display cards
	* dealer cards
	MOVE.W	#Card_Left,RX			; set X value of first card
	MOVE.W	#Dealer_Card_Top,RY		; set Y value of cards
	for.w D6 = #1 to #5 do.s		; loop 5 times
	  DRAWRECT RX,RY,RW,RH			;   draw card
	  ADDCARDBACKTEXT RX,RY			;   display card back text
	  ADD.W #(Card_Width+Card_Gap),RX	;   shift the X value for next card
	endf					; end loop
	
	* player cards
	MOVE.W	#Card_Left,RX			; set X value of first card
	MOVE.W	#Player_Card_Top,RY		; set Y of cards
	for.w D6 = #1 to #5 do.s		; loop 5 times
	  DRAWRECT RX,RY,RW,RH			;   draw card
	  ADDCARDBACKTEXT RX,RY			;   display card back text
	  ADD.W #(Card_Width+Card_Gap),RX	;   shift the X value for next card
	endf					; end loop
	
	* Restore table colors
	SETPENCOLOR  #CREAM			; set pen color
	SETFILLCOLOR #TABLEGREEN		; set fill color
	
	* Draw table text
	* dealer text
	LEA	tableProp_dealer,A1		; move the address of the text string into A1
	MOVE.W	#40,D1				; move x coordinate into D1.W
	MOVE.W	#85,D2				; move y coordinate into D2.W
	MOVE.B	#95,D0				; print null terminated string with x,y coord
	TRAP	#15				; run the task
	* dealer score text
	LEA	tableProp_score,A1		; move the address of the text string into A1
	ADD.W	#18,D2				; move y coordinate into D2.W
	TRAP	#15				; run the task
	* dealer wins
	LEA	tempCardString,A1		; load the card temp string into A2
	MOVE.B	dealerWins,D1			; move temp card into D1
	DIV10	D1				;   get tens value
	if D1 <eq> #0 then			; check for a zero
	  MOVE.B #$20,D1			;   move a space into D1
	else					; else
	  ADD.B	#$30,D1				;   convert number to hex
	endi					; end if
	MOVE.B	#0,D3				; set the string position counter to 0
	MOVE.B	D1,(A1,D3)			; 10's position
	MOVE.B	dealerWins,D1			; move temp card into D1
	MOD	D1				; get ones value
	ADD.B	#$30,D1				; convert number to hex
	MOVE.B	#1,D3				; set the string position counter to 1
	MOVE.B	D1,(A1,D3)			; 1's position
	DRAWTEXT #90,#103,tempCardString	; print the player score

	* player text
	LEA	tableProp_player,A1		; move the address of the text string into A1
	MOVE.W	#40,D1				; move x coordinate into D1.W
	MOVE.W	#345,D2				; move y coordinate into D2.W
	TRAP	#15				; run the task
	* player score text
	LEA	tableProp_score,A1		; move the address of the text string into A1
	ADD.W	#18,D2				; move y coordinate into D2.W
	TRAP	#15				; run the task
	* player wins
	LEA	tempCardString,A1		; load the card temp string into A2
	MOVE.B	playerWins,D1			; move temp card into D1
	DIV10	D1				;   get tens value
	if D1 <eq> #0 then			; check for a zero
	  MOVE.B #$20,D1			;   move a space into D1
	else					; else
	  ADD.B	#$30,D1				;   convert number to hex
	endi					; end if
	MOVE.B	#0,D3				; set the string position counter to 0
	MOVE.B	D1,(A1,D3)			; 10's position
	MOVE.B	playerWins,D1			; move temp card into D1
	MOD	D1				; get ones value
	ADD.B	#$30,D1				; convert number to hex
	MOVE.B	#1,D3				; set the string position counter to 1
	MOVE.B	D1,(A1,D3)			; 1's position
	DRAWTEXT #90,#363,tempCardString	; print the player score
	
	* Display game title
	LEA	tableProp_title,A1		; move the address of the text string into A1
	MOVE.W	#345,D1				; move x coordinate into D1.W
	MOVE.W	#190,D2				; move y coordinate into D2.W
	TRAP	#15				; run the task
	
	* Display game author
	LEA	tableProp_author,A1		; move the address of the text string into A1
	SUB.W	#7,D1				; move x coordinate into D1.W
	ADD.W	#20,D2				; move y coordinate into D2.W
	TRAP	#15				; run the task
	
	* Display game class
	LEA	tableProp_class,A1		; move the address of the text string into A1
	SUB.W	#50,D1				; move x coordinate into D1.W
	ADD.W	#20,D2				; move y coordinate into D2.W
	TRAP	#15				; run the task
	
	* Display game date
	LEA	tableProp_date,A1		; move the address of the text string into A1
	ADD.W	#57,D1				; move x coordinate into D1.W
	ADD.W	#20,D2				; move y coordinate into D2.W
	TRAP	#15				; run the task
	
	RTS

*Finish the game, say good bye
FinishGame
	BSR	ClearTable			; clear the table
	BSR	DrawTable			; draw the table
	
	* Clear the status
	SETPENCOLOR  #CREAM			; set pen color
	SETFILLCOLOR #CREAM			; set fill color
	DRAWRECT #250,#500,#300,#100		; clear the status
	
	* Print goodbye text
	SETFILLCOLOR 	#BLACK			; set fill color
	DRAWTEXT 	#283,#540,gameover_text
	RTS

*Generate a random number
***Not the best way to generate a random number because it's not very random,
***but will work for this purpose because the deck becomes more random as the
***game is played.
* D0 = task holder
* D1 = return number
* D4 = deck array limit
GetRandomNumber
	MOVE.B	#8,D0				; return time in hundreds of a second
	TRAP	#15				; run the task
	AND.L	#$5FFFF,D1			; prevent overflow in divu
	DIVU	D4,D1				; time count / max number
	SWAP	D1				; swap upper and lower words of D1 to get remainder	
	EXT.L	D1				; convert lower word to long
	RTS

*Select/Deselect cards by displaying highlighting
HighlightCards
	* Draw discard button
	SETPENCOLOR	#LTGRAY
	SETFILLCOLOR	#DARKGRAY
	DRAWRECT 	#Discard_Button_Left,#Discard_Button_Top,#Discard_Button_Width,#Discard_Button_Height
	if.b discardCount <eq> #0 then
	  DRAWTEXT 	#(Discard_Button_Left+25),#(Discard_Button_Top+18),discard_button_text_0
	else
	  DRAWTEXT 	#(Discard_Button_Left+25),#(Discard_Button_Top+18),discard_button_text_1
	endi
	for.w D6 = #0 to #4 do.s		; loop 5 times
	  if.b (A3,D6) <eq> #1 then
	    SETPENCOLOR #PLAYERWINC		; set pen color
	    SETFILLCOLOR #PLAYERWINC		; set fill color
	    BSR DrawHighlight			; draw the highlighting
	  else
	    SETPENCOLOR #TABLEGREEN		; set pen color
	    SETFILLCOLOR #TABLEGREEN		; set fill color
	    BSR DrawHighlight			; draw the highlighting
	  endi
	endf					; end for
	RTS

*Initialize the game
InitializeGame
	* Set window size
	MOVE.B	#33,D0				; set screen resolution
	MOVE.L	#(Table_Width<<16+Table_Height),D1	; Table resolution
	TRAP	#15				; run the task
	
	* Initialize IRQ vectors 
	MOVE.L	#mouseDownIRQ,$68		; IRQ2
	MOVE.B	#60,D0				; set mouse IRQ
	MOVE.W	#$0201,D1			; IRQ2 for mouse down
	TRAP	#15				; run the task
	
	* Enable Exceptions
	MOVE.B	#32,D0				; Simulator Environment
	MOVE.B	#05,D1				; Enable Exceptions
	TRAP	#15				; run the task
	
	* Turn off echo
	ECHO_OFF
	
	* Set game mode
	MOVE.B	#DEBUGMODE,var_gameMode		; set game mode
	RTS

*Manage the player hand after discard
ManagePlayerHand
	LEA	playerHand,A5			; load the player hand into A5
	BSR	CheckHand			; check the players hand
	MOVE.B	D2,playerScore			; get the players score
	MOVE.L	D3,playerScoreCards		; get the players score cards
	MOVE.W	#Player_Card_Top,RY		; set Y of cards
	BSR	PrintHandGfx			; print the hand graphics
	RTS

*Manage the dealer hand after discard
ManageDealerHand
	LEA	dealerHand,A5			; load the dealer hand into A5
	BSR	CheckHand			; check the dealers hand
	MOVE.B	D2,dealerScore			; get the dealers score
	MOVE.L	D3,dealerScoreCards		; get the dealers score cards
	MOVE.W	#Dealer_Card_Top,RY		; set Y of cards
	BSR	PrintHandGfx			; print the hand graphics
	RTS

*Manage the new hand prompt and determination
ManageNewHandPrompt
	MOVE.B	#7,D0				; check for pending key press
	TRAP	#15				; run the task
	if.b D1 <ne> #0 then.s			; if key is ready and new hand prompt is displayed
	  SETPENCOLOR  #TABLEGREEN		; set pen color
	  SETFILLCOLOR #TABLEGREEN		; set fill color
	  MOVE.B #5,D0				;   read key to clear buffer
	  TRAP #15				;   run the task
	endi					; end if
	BSR	PromptForNewHand		; ask if the player wants to play another game
	CLR.L	D3				; clear D3 (used to determine mouse down)
	CLR.L	D4				; clear D4 (used to determine yes or no)
	BSR	Pause				; pause for user input
	RTS

*Pause the program
* D3 = 1 indicates mouse click on a button
* D4 = 0 for click on No, 1 for click on Yes
Pause
	DELAY		1			; delay for 1/100 seconds
	
	* Check for F8 Key to change game mode
	MOVE.B	#7,D0				; check for pending key press
	TRAP	#15				; run the task
	if.b D1 <ne> #0 and D7 <eq> #4 then.s	; if key is ready and new hand prompt is displayed
	  MOVE.B #5,D0				;   read key
	  TRAP #15				;   run the task
	  if.b d1 <eq> #'8' then.s		;   if '8' pressed
	    if.b var_gameMode <eq> #1 then	;     if test mode
	      MOVE.B	#0,var_gameMode		;       set to normal mode
	      BRA GAME				;       restart the game loop
	    else				;     else
	      MOVE.B	#1,var_gameMode		;       set to test mode
	      BRA GAME				;       restart the game loop
	    endi				;     end if
	  endi					;   end if
	endi					; end if
	
	* Loop
	if D3 <ne> #1 then			; if mouse was not clicked
	  BRA		Pause			;   continue to loop
	endi					; end if
	RTS

*Handle discard routine
PauseForDiscard
	CLR.L	D3				;   clear D3 to await user input
	BSR	PromptForDiscard		;   ask the player which cards to discard
	LEA	discardArray,A3			;   load discard array into A3
	BSR	Pause				;   pause for user input
	
	* Clear the discard buttons
	BSR	ClearDiscardButtons
	
	* Replace the selected cards
	BSR	SwapPlayerCards
	RTS

*Print the graphics of a hand
* Y value is set before this sub is called
PrintHandGfx
	MOVE.W	#Card_Left,RX			; set X value of first card
	MOVE.W	#Card_Width,RW			; set width
	MOVE.W	#Card_Height,RH			; set height
	for.w D6 = #0 to #4 do.s		; loop 5 times
	  DRAWRECT RX,RY,RW,RH			;   draw card
	  MOVE.W #0,D1				;   clear D1.W
	  MOVE.B (A5,D6),D1			;   move card into D1
	  MOVE.W D1,tempCard			;   set card number
	  BSR AddCardText			;   display card text
	  ADD.W #(Card_Width+Card_Gap),RX	;   shift the X value for next card
	endf					; end loop
	RTS

*Prompt the player for discard
PromptForDiscard
	* Draw discard button
	SETPENCOLOR	#LTGRAY
	SETFILLCOLOR	#DARKGRAY
	DRAWRECT 	#Discard_Button_Left,#Discard_Button_Top,#Discard_Button_Width,#Discard_Button_Height
	DRAWTEXT 	#(Discard_Button_Left+25),#(Discard_Button_Top+18),discard_button_text_0
	
	* Update the status
	SETPENCOLOR	#CREAM
	SETFILLCOLOR	#BLACK
	DRAWTEXT	#269,#524,discard_text1
	DRAWTEXT	#340,#544,discard_text2
	SETPENCOLOR	#BLACK
	SETFILLCOLOR	#WHITE
	RTS

*Prompt the player for a new hand
PromptForNewHand
	*set prompt colors
	SETPENCOLOR	#WHITE
	SETFILLCOLOR	#BLACK
	*draw outer rectangle
	DRAWRECT	#NewHand_Prompt_Left,#NewHand_Prompt_Top,#NewHand_Prompt_Width,#NewHand_Prompt_Height
	*draw prompt text
	DRAWTEXT	#NewHand_Text_Left,#NewHand_Text_Top,NewHand_Prompt_Text
	*set button colors
	SETFILLCOLOR	#DARKGRAY
	*draw yes button
	DRAWRECT	#Yes_Button_Left,#YesNo_Button_Top,#YesNo_Button_Width,#YesNo_Button_Height
	DRAWTEXT	#Yes_Button_Text_Left,#Yes_Button_Text_Top,Yes_Button_Text
	*draw no button
	DRAWRECT	#No_Button_Left,#YesNo_Button_Top,#YesNo_Button_Width,#YesNo_Button_Height
	DRAWTEXT	#No_Button_Text_Left,#No_Button_Text_Top,No_Button_Text
	RTS

*Shuffle the deck
* D4 = deck array limit
Shuffle
	MOVE.B	#52,D4				; reset limit to all cards
	RTS

*Sort a hand
* D6 = outer counter
* D3 = inner counter
* D5 = temp storage during card swap
SortHand
	for.w D6 = #0 to #3 do.s		; loop through the hand
	  for.w D3 = D6 to #4 do.s		;   loop from current card to end of hand
	    MOVE.B	(A5,D6),D1		;     move the current card into D1
	    MOVE.B	(A5,D3),D2		;     move the check card into D2
	    if D2 <gt> D1 then			;     if the check card is larger
	      MOVE.B	(A5,D6),D5
	      MOVE.B	(A5,D3),(A5,D6)		;       swap the cards
	      MOVE.B	D5,(A5,D3)
	    endi				;     end if
	  endf					;   end for
	endf					; end for
	RTS

*Swap player cards
SwapPlayerCards
	*display number of cards discarded
	SETPENCOLOR	#LTGRAY			; set pen color
	SETFILLCOLOR	#PLAYERWINC		; set fill color
	MOVE.B		#18,D0			; move 18 into D0
	MOVE.B		discardCount,D1		; move discard count into D1
	ADD.B		#$30,D1			; convert number to hex
	LEA		var_playerSwapText,A5	; load player swap text into A5
	MOVE.B		D1,(A5,D0)		; move the count into the string
	DRAWRECT 	#(Table_Width/2-83),#(Player_Card_Bottom+5),#166,#20
	DRAWTEXT 	#(Table_Width/2-75),#(Player_Card_Bottom+8),var_playerSwapText
	SETPENCOLOR	#BLACK			; set pen color
	SETFILLCOLOR	#WHITE			; set fill color
	
	*deal new cards
	LEA		discardArray,A3		; load discard array into A3
	LEA		playerHand,A4		; load player hand into A4
	for.w D6 = #0 to #4 do.s		; loop 5 times
	  if.b (A3,D6) <eq> #1 then		;   if card was selected
	    BSR		Deal			;     deal a new card
	    MOVE.B	D5,(A4,D6)		;     move the card into the players hand
	    MOVE.B	#0,(A3,D6)		;     reset the discard array for dealer use
	  endi					;   end if
	endf					; end for
	
	*reset the discard count for dealer use
	MOVE.B		#0,discardCount
	RTS

*Test mode
* D6 = loop counter
TestMode
	ECHO_ON
	PRINT	testModeDetails			; print the test mode details
	LEA	playerHand,A5			; load the player hand into A5
	for.w D6 = #0 to #4 do.s		; loop through the players hand
	  PRINT		promptPlayer		;   display player card prompt
	  GETNUM	D5			;   get a number from the user
	  MOVE.B	D5,(A5,D6)		;   move the card into the players hand
	endf					; end for
	PRINT	endl				; print new line
	LEA	dealerHand,A5			; load the dealer hand into A5
	for.w D6 = #0 to #4 do.s		; loop through the dealers hand
	  PRINT		promptDealer		;   display dealer card prompt
	  GETNUM	D5			;   get a number from the user
	  MOVE.B	D5,(A5,D6)		;   move the card into the dealers hand
	endf					; end for
	PRINT	endl				; print new line
	ECHO_OFF
	RTS

*Display the winning hand
UpdateWinner
	* Clear the status
	SETPENCOLOR  #CREAM			; set pen color
	SETFILLCOLOR #CREAM			; set fill color
	DRAWRECT #250,#500,#300,#100		; clear the status
	
	* Count a win for the winner
	if.b D5 <eq> #1 then			; if D5 = 1 then
	  ADD.B #1,playerWins			;   increment player wins
	  SETFILLCOLOR #PLAYERWINC		;   set fill color
	  LEA playerWinText,A3			;   load the winning text into A1
	  MOVE.B playerScore,D1			;   load the player score for status update
	  LEA	playerHand,A5			;   load the player hand into A5
	else					; else
	  MOVE.B dealerScore,D1			;   load the dealer score for status update
	  LEA	dealerHand,A5			;   load the player hand into A5
	  if D5 <eq> #2 then			;   if D5 = 2 then
	    SETFILLCOLOR #DRAWWINC		;     set fill color
	    LEA drawWinText,A3			;     load the winning text into A1
	  else					;   else
	    ADD.B #1,dealerWins			;     increment dealer wins
	    SETFILLCOLOR #DEALERWINC		;     set fill color
	    LEA dealerWinText,A3		;     load the winning text into A1
	  endi					;   end if
	endi					; end if
	
	* Display winner panel
	SETPENCOLOR  #WHITE			; set pen color
	DRAWRECT #276,#177,#250,#100		; draw table
	DRAWTEXT #330,#218,(A3)			; print the player score
	
	* Display winner status
	MOVE.L	#0,D6				; get first card in the hand
	MOVE.B	(A5,D6),D5			; move card number into D5
	DIV10	D5				; extract the card value
	
	if D1 <eq> #8 then
	  LEA	winning_text8,A1		; load the card winning text into A1
	endi
	if D1 <eq> #7 then
	  LEA	winning_text7,A1		; load the card winning text into A1
	endi
	if D1 <eq> #6 then
	  LEA	winning_text6,A1		; load the card winning text into A1
	endi
	if D1 <eq> #5 then
	  LEA	winning_text5,A1		; load the card winning text into A1
	endi
	if D1 <eq> #4 then
	  LEA	winning_text4,A1		; load the card winning text into A1
	endi
	if D1 <eq> #3 then
	  LEA	winning_text3,A1		; load the card winning text into A1
	endi
	if D1 <eq> #2 then
	  LEA	winning_text2,A1		; load the card winning text into A1
	endi
	if D1 <eq> #1 then
	  LEA	winning_text1,A1		; load the card winning text into A1
	endi
	if D1 <eq> #0 then
	  if D5 <eq> #14 then
	    LEA	winning_text0_14,A1		; load the card winning text into A1
	  endi
	  if D5 <eq> #13 then
	    LEA	winning_text0_13,A1		; load the card winning text into A1
	  endi
	  if D5 <eq> #12 then
	    LEA	winning_text0_12,A1		; load the card winning text into A1
	  endi
	  if D5 <eq> #11 then
	    LEA	winning_text0_11,A1		; load the card winning text into A1
	  endi
	  if D5 <eq> #10 then
	    LEA	winning_text0_10,A1		; load the card winning text into A1
	  endi
	  if D5 <eq> #9 then
	    LEA	winning_text0_9,A1		; load the card winning text into A1
	  endi
	  if D5 <eq> #8 then
	    LEA	winning_text0_8,A1		; load the card winning text into A1
	  endi
	  if D5 <eq> #7 then
	    LEA	winning_text0_7,A1		; load the card winning text into A1
	  endi
	endi
	
	* draw the status
	SETPENCOLOR	#CREAM			; set pen color
	SETFILLCOLOR	#BLACK			; set fill color
	DRAWTEXT	#319,#532,(A1)		; display the winning text
	
	* Display wins
	SETPENCOLOR  #CREAM			; set pen color
	SETFILLCOLOR #TABLEGREEN		; set fill color
	
	* dealer wins
	CLR.L	D1				; clear D1
	LEA	tempCardString,A1		; load the card temp string into A1
	MOVE.B	dealerWins,D1			; move temp card into D1
	if D1 <eq> #99 then			; check for a score of 99
	  BRA EXITGAME				;   exit the game
	endi					; end if
	DIV10	D1				;   get tens value
	if D1 <eq> #0 then			; check for a zero
	  MOVE.B #$20,D1			;   move a space into D1
	else					; else
	  ADD.B	#$30,D1				;   convert number to hex
	endi					; end if
	MOVE.L	#0,D3				; set the string position counter to 0
	MOVE.B	D1,(A1,D3)			; 10's position
	MOVE.B	dealerWins,D1			; move temp card into D1
	MOD	D1				; get ones value
	ADD.B	#$30,D1				; convert number to hex
	MOVE.B	#1,D3				; set the string position counter to 1
	MOVE.B	D1,(A1,D3)			; 1's position
	DRAWTEXT #90,#103,tempCardString	; print the player score
	
	* player wins
	LEA	tempCardString,A1		; load the card temp string into A1
	MOVE.B	playerWins,D1			; move temp card into D1
	if D1 <eq> #99 then			; check for a score of 99
	  BRA EXITGAME				;   exit the game
	endi					; end if
	DIV10	D1				;   get tens value
	if D1 <eq> #0 then			; check for a zero
	  MOVE.B #$20,D1			;   move a space into D1
	else					; else
	  ADD.B	#$30,D1				;   convert number to hex
	endi					; end if
	MOVE.B	#0,D3				; set the string position counter to 0
	MOVE.B	D1,(A1,D3)			; 10's position
	MOVE.B	playerWins,D1			; move temp card into D1
	MOD	D1				; get ones value
	ADD.B	#$30,D1				; convert number to hex
	MOVE.B	#1,D3				; set the string position counter to 1
	MOVE.B	D1,(A1,D3)			; 1's position
	DRAWTEXT #90,#363,tempCardString	; print the player score
	RTS



*----------------------------------------------------
* Sub Routines - Check Hand Functions
*----------------------------------------------------
* D2 = return score
* D3 = return hand value
* D0 = temp variable
* D1 = temp variable
* A5 = hand pointer
* D5 = hand array index

*8.x
CheckStraightFlush
						;*** check for a flush
	GETSUIT #0,D0				; get suit of card
	GETSUIT #1,D1				; get suit of card
	if D0 <eq> D1 then			; check if they are equal
	  GETSUIT #2,D1				;   get suit of card
	  if D0 <eq> D1 then			;   check if they are equal
	    GETSUIT #3,D1			;     get suit of card
	    if D0 <eq> D1 then			;     check if they are equal
	      GETSUIT #4,D1			;       get suit of card
	      if D0 <eq> D1 then		;       check if they are equal
	      					;*** check for a straight
	        				;*** check special case: ace low straight
	        GETVAL #0,D0			;         get value of card
	        if D0 <eq> #14 then		;         check if card 1 is an ace
	          GETVAL #1,D0			;           get value of card
	          if D0 <eq> #5 then		;           check if card 2 is a 5
	            GETVAL #2,D0		;             get value of card
	            if D0 <eq> #4 then		;             check if card 3 is a 4
	              GETVAL #3,D0		;               get value of card
	              if D0 <eq> #3 then	;               check if card 4 is a 3
	                GETVAL #4,D0		;                 get value of card
	                if D0 <eq> #2 then	;                 check if card 5 is a 2
	                  MOVE.B #8,D2		;                  return low straight flush
	                  MOVE.B #5,D3		;                  return hand value
	                  BRA SuccessSF		;                  branch to success
	                endi			;                 end if
	              endi			;               end if
	            endi			;             end if
	          endi				;           end if
	        endi				;         end if
	        				;*** check normal case: straight
	        GETVAL #0,D0			;         get value of card
	        GETVAL #1,D1			;         get value of card
	        SUB.B #1,D0			;         subtract 1 from D0
	        if D0 <eq> D1 then		;         check if card 1 + 1 = card 2
	          GETVAL #2,D1			;           get value of card
	          SUB.B #1,D0			;           subtract 1 from D0
	          if D0 <eq> D1 then		;           check if card 1 + 2 = card 3
	            GETVAL #3,D1		;             get value of card
	            SUB.B #1,D0			;             subtract 1 from D0
	            if D0 <eq> D1 then		;             check if card 1 + 3 = card 4
	              GETVAL #4,D1		;               get value of card
	              SUB.B #1,D0		;               subtract 1 from D0
	              if D0 <eq> D1 then	;               check if card 1 + 4 = card 5
	                MOVE.B #8,D2		;                 return straight flush
	                GETVAL #0,D3		;                 return hand value
	              endi			;               end if
	            endi			;             end if
	          endi				;           end if
	        endi				;         end if
	      endi				;       end if
	    endi				;     end if
	  endi					;   end if
	endi					; end if
SuccessSF
	RTS
*7.x
CheckFourofaKind
	GETVAL #0,D0				; get value of card
	GETVAL #3,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #7,D2				;   return four of a kind
	  MOVE.B D0,D3				;   return hand value
	  BRA Success4K				;   branch to success
	endi					; end if
	GETVAL #1,D0				; get value of card
	GETVAL #4,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #7,D2				;   return four of a kind
	  MOVE.B D0,D3				;   return hand value
	endi					; end if
Success4K
	RTS
*6.x
CheckFullHouse
	GETVAL #0,D0				; get value of card
	GETVAL #1,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  GETVAL #2,D0				;   get value of card
	  GETVAL #4,D1				;   get value of card
	  if D0 <eq> D1 then			;   check if they are equal
	    MOVE.B #6,D2			;     return full house
	    MOVE.B D0,D3			;     return hand value
	    ASL.L #8,D3				;     shift the value to the left
	    GETVAL #0,D0			;     get the value of the kicker
	    MOVE.B D0,D3			;     return hand value
	    BRA SuccessFH			;     branch to success
	  endi					;   end if
	endi					; end if
	GETVAL #0,D0				; get value of card
	GETVAL #2,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  GETVAL #3,D0				;   get value of card
	  GETVAL #4,D1				;   get value of card
	  if D0 <eq> D1 then			;   check if they are equal
	    MOVE.B #6,D2			;     return full house
	    GETVAL #0,D0			;     get the value of the kicker
	    MOVE.B D0,D3			;     return hand value
	    ASL.L #8,D3				;     shift the value to the left
	    GETVAL #3,D0			;     get the value of the kicker
	    MOVE.B D0,D3			;     return hand value
	  endi					;   end if
	endi					; end if
SuccessFH
	RTS
*5.x
CheckFlush
	GETSUIT #0,D0				; get suit of card
	GETSUIT #1,D1				; get suit of card
	if D0 <eq> D1 then			; check if they are equal
	  GETSUIT #2,D1				;   get suit of card
	  if D0 <eq> D1 then			;   check if they are equal
	    GETSUIT #3,D1			;     get suit of card
	    if D0 <eq> D1 then			;     check if they are equal
	      GETSUIT #4,D1			;       get suit of card
	      if D0 <eq> D1 then		;       check if they are equal
	        MOVE.B #5,D2			;         return flush
	      endi				;       end if
	    endi				;     end if
	  endi					;   end if
	endi					; end if
	RTS
*4.x
CheckStraight
  						;*** check special case: ace low straight
	GETVAL #0,D0				; get value of card
	if D0 <eq> #14 then			; check if card 1 is an ace
	  GETVAL #1,D0				;   get value of card
	  if D0 <eq> #5 then			;   check if card 2 is a 5
	    GETVAL #2,D0			;     get value of card
	    if D0 <eq> #4 then			;     check if card 3 is a 4
	      GETVAL #3,D0			;       get value of card
	      if D0 <eq> #3 then		;       check if card 4 is a 3
	        GETVAL #4,D0			;         get value of card
	        if D0 <eq> #2 then		;         check if card 5 is a 2
	          MOVE.B #4,D2			;           return low straight
	          MOVE.B #5,D3			;           return hand value
                  BRA SuccessST			;           branch to success
                endi				;         end if
              endi				;       end if
            endi				;     end if
          endi					;   end if
        endi					; end if
	        				;*** check normal case: straight
	GETVAL #0,D0				; get value of card
	GETVAL #1,D1				; get value of card
	SUB.B #1,D0				; subtract 1 from D0
	if D0 <eq> D1 then			; check if card 1 + 1 = card 2
	  GETVAL #2,D1				;   get value of card
          SUB.B #1,D0				;   subtract 1 from D0
          if D0 <eq> D1 then			;   check if card 1 + 2 = card 3
            GETVAL #3,D1			;     get value of card
            SUB.B #1,D0				;     subtract 1 from D0
            if D0 <eq> D1 then			;     check if card 1 + 3 = card 4
              GETVAL #4,D1			;       get value of card
              SUB.B #1,D0			;       subtract 1 from D0
              if D0 <eq> D1 then		;       check if card 1 + 4 = card 5
                MOVE.B #4,D2			;         return straight
                GETVAL #0,D3			;         return hand value
              endi				;       end if
            endi				;     end if
          endi					;   end if
        endi					; end if
SuccessST
	RTS
*3.x
CheckThreeofaKind
	GETVAL #0,D0				; get value of card
	GETVAL #2,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #3,D2				;   return three of a kind
	  MOVE.B D0,D3				;   return hand value
	  BRA Success3K				;   branch to success
	endi					; end if
	GETVAL #1,D0				; get value of card
	GETVAL #3,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #3,D2				;   return three of a kind
	  MOVE.B D0,D3				;   return hand value
	  BRA Success3K				;   branch to success
	endi					; end if
	GETVAL #2,D0				; get value of card
	GETVAL #4,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #3,D2				;   return three of a kind
	  MOVE.B D0,D3				;   return hand value
	endi					; end if
Success3K
	RTS
*2.x
CheckTwoPair
	GETVAL #0,D0				; get value of card
	GETVAL #1,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  GETVAL #2,D0				;   get value of card
	  GETVAL #3,D1				;   get value of card
	  if D0 <eq> D1 then			;   check if they are equal
	    MOVE.B #2,D2			;     return two pair
	    
	    GETVAL #0,D0			;     get the value of the high pair
	    MOVE.B D0,D3			;     return hand value
	    ASL.L #8,D3				;     shift the value to the left
	    GETVAL #2,D0			;     get the value of the low pair
	    MOVE.B D0,D3			;     return hand value
	    ASL.L #8,D3				;     shift the value to the left
	    GETVAL #4,D0			;     get the value of the kicker
	    MOVE.B D0,D3			;     return hand value
	    
	    BRA Success2P			;     branch to success
	  endi					;   end if
	endi					; end if
	GETVAL #0,D0				; get value of card
	GETVAL #1,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  GETVAL #3,D0				;   get value of card
	  GETVAL #4,D1				;   get value of card
	  if D0 <eq> D1 then			;   check if they are equal
	    MOVE.B #2,D2			;     return two pair
	    
	    GETVAL #0,D0			;     get the value of the high pair
	    MOVE.B D0,D3			;     return hand value
	    ASL.L #8,D3				;     shift the value to the left
	    GETVAL #3,D0			;     get the value of the low pair
	    MOVE.B D0,D3			;     return hand value
	    ASL.L #8,D3				;     shift the value to the left
	    GETVAL #2,D0			;     get the value of the kicker
	    MOVE.B D0,D3			;     return hand value
	    
	    BRA Success2P			;     branch to success
	  endi					;   end if
	endi					; end if
	GETVAL #1,D0				; get value of card
	GETVAL #2,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  GETVAL #3,D0				;   get value of card
	  GETVAL #4,D1				;   get value of card
	  if D0 <eq> D1 then			;   check if they are equal
	    MOVE.B #2,D2			;     return two pair
	    
	    GETVAL #1,D0			;     get the value of the high pair
	    MOVE.B D0,D3			;     return hand value
	    ASL.L #8,D3				;     shift the value to the left
	    GETVAL #3,D0			;     get the value of the low pair
	    MOVE.B D0,D3			;     return hand value
	    ASL.L #8,D3				;     shift the value to the left
	    GETVAL #0,D0			;     get the value of the kicker
	    MOVE.B D0,D3			;     return hand value
	    
	  endi					;   end if
	endi					; end if
Success2P
	RTS
*1.x
CheckOnePair
	GETVAL #0,D0				; get value of card
	GETVAL #1,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #1,D2				;   return two pair
	  
	  GETVAL #0,D0				;   get the value of the pair
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #2,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #3,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #4,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  
	  BRA Success1P				;   branch to success
	endi					; end if
	GETVAL #1,D0				; get value of card
	GETVAL #2,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #1,D2				;   return two pair
	  
	  GETVAL #1,D0				;   get the value of the pair
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #0,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #3,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #4,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  
	  BRA Success1P				;   branch to success
	endi					; end if
	GETVAL #2,D0				; get value of card
	GETVAL #3,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #1,D2				;   return two pair
	  
	  GETVAL #2,D0				;   get the value of the pair
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #0,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #1,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #4,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  
	  BRA Success1P				;   branch to success
	endi					; end if
	GETVAL #3,D0				; get value of card
	GETVAL #4,D1				; get value of card
	if D0 <eq> D1 then			; check if they are equal
	  MOVE.B #1,D2				;   return two pair
	  
	  GETVAL #3,D0				;   get the value of the pair
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #0,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #1,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  ASL.L #8,D3				;   shift the value to the left
	  GETVAL #2,D0				;   get the value of the cards in order
	  MOVE.B D0,D3				;   return hand value
	  
	endi					; end if
Success1P
	RTS



********************** IRQ HANDLERS ***********************************
* Special thanks to Daniel Strimpel and Chuck Kelly for providing
* this mouse handler function.

* Mouse Down handler
mouseDownIRQ
	if.b d7 <eq> #2 or d7 <eq> #4 then
	  movem.l	d0-d2,-(sp)
	  move.b	#61,d0			; read mouse
	  move.b	#2,d1			; mouse down state
	  trap		#15
	  clr.l		d2
	  move.w	d1,d2			; d2 is mouse X
	  swap		d1			; d1 is mouse Y
	  and.l		#$0FFFF,d1
	
	; if mouse inside discard button or select cards
	if.b d7 <eq> #2 then
	  if.w d1 <hs> #Player_Card_Top and.w d1 <ls> #Player_Card_Bottom then
	    * discard button
	    if.w d1 <hs> #Discard_Button_Top and.w d1 <ls> #Discard_Button_Bottom then
	      if.w d2 <hs> #Discard_Button_Left and.w d2 <ls> #Discard_Button_Right then
                move.b	#1,d3
                BRA	ExitMD
              endi
	    endi
	    
	    * select cards
	    * A3 = discardArray
	    
	    * card 1
	    if.w d2 <hs> #Player_Card1_Left and.w d2 <ls> #Player_Card1_Right then
	      MOVE.B	#0,D0
	      CLR.L	D5
	      MOVE.B	(A3,D0),D5
	      if.b D5 <eq> #1 then
	        MOVE.B	#0,(A3,D0)
	        SUB.B	#1,discardCount
	        BSR	HighlightCards
	        BRA	ExitMD
	      else
	        MOVE.B	discardCount,D5
	        if.b D5 <lo> #3 then
	          MOVE.B #1,(A3,D0)
	          ADD.B #1,discardCount
	          BSR	HighlightCards
	          BRA	ExitMD
	        endi
	      endi
	    endi
	    
	    * card 2
	    if.w d2 <hs> #Player_Card2_Left and.w d2 <ls> #Player_Card2_Right then
	      MOVE.B	#1,D0
	      CLR.L	D5
	      MOVE.B	(A3,D0),D5
	      if.b D5 <eq> #1 then
	        MOVE.B	#0,(A3,D0)
	        SUB.B	#1,discardCount
	        BSR	HighlightCards
	        BRA	ExitMD
	      else
	        MOVE.B	discardCount,D5
	        if.b D5 <lo> #3 then
	          MOVE.B #1,(A3,D0)
	          ADD.B #1,discardCount
	          BSR	HighlightCards
	          BRA	ExitMD
	        endi
	      endi
	    endi
	    
	    * card 3
	    if.w d2 <hs> #Player_Card3_Left and.w d2 <ls> #Player_Card3_Right then
	      MOVE.B	#2,D0
	      CLR.L	D5
	      MOVE.B	(A3,D0),D5
	      if.b D5 <eq> #1 then
	        MOVE.B	#0,(A3,D0)
	        SUB.B	#1,discardCount
	        BSR	HighlightCards
	        BRA	ExitMD
	      else
	        MOVE.B	discardCount,D5
	        if.b D5 <lo> #3 then
	          MOVE.B #1,(A3,D0)
	          ADD.B #1,discardCount
	          BSR	HighlightCards
	          BRA	ExitMD
	        endi
	      endi
	    endi
	    
	    * card 4
	    if.w d2 <hs> #Player_Card4_Left and.w d2 <ls> #Player_Card4_Right then
	      MOVE.B	#3,D0
	      CLR.L	D5
	      MOVE.B	(A3,D0),D5
	      if.b D5 <eq> #1 then
	        MOVE.B	#0,(A3,D0)
	        SUB.B	#1,discardCount
	        BSR	HighlightCards
	        BRA	ExitMD
	      else
	        MOVE.B	discardCount,D5
	        if.b D5 <lo> #3 then
	          MOVE.B #1,(A3,D0)
	          ADD.B #1,discardCount
	          BSR	HighlightCards
	          BRA	ExitMD
	        endi
	      endi
	    endi
	    
	    * card 5
	    if.w d2 <hs> #Player_Card5_Left and.w d2 <ls> #Player_Card5_Right then
	      MOVE.B	#4,D0
	      CLR.L	D5
	      MOVE.B	(A3,D0),D5
	      if.b D5 <eq> #1 then
	        MOVE.B	#0,(A3,D0)
	        SUB.B	#1,discardCount
	        BSR	HighlightCards
	        BRA	ExitMD
	      else
	        MOVE.B	discardCount,D5
	        if.b D5 <lo> #3 then
	          MOVE.B #1,(A3,D0)
	          ADD.B #1,discardCount
	          BSR	HighlightCards
	          BRA	ExitMD
	        endi
	      endi
	    endi

	  endi
	endi
	
	; if mouse inside yes or no button
	if.b d7 <eq> #4 then
	  if.w d1 <hi> #YesNo_Button_Top and.w d1 <lo> #YesNo_Button_Bottom then
            if.w d2 <hs> #Yes_Button_Left and.w d2 <ls> #Yes_Button_Right then
              move.b	#1,d4
              move.b	#1,d3
            endi
            if.w d2 <hs> #No_Button_Left and.w d2 <ls> #No_Button_Right then
              move.b	#1,d3
            endi
	  endi
	endi
ExitMD
	  movem.l	(sp)+,d0-d2
	endi
	rte



********************** VARIABLES **************************************

endl		DC.B	$0D,$0A,0
cardbacktext	DC.B	'MCCC',0

* New hand prompt text
NewHand_Prompt_Text	DC.B	'Play another hand?',0
Yes_Button_Text		DC.B	'Yes',0
No_Button_Text		DC.B	'No',0

tableProp_dealer	DC.B	'Dealers Hand',0
tableProp_player	DC.B	'Players Hand',0
tableProp_score		DC.B	'Wins:',0
tableProp_title		DC.B	'Five Card Draw',0
tableProp_author	DC.B	'by Nicholas Loar',0
tableProp_class		DC.B	'CIS 268 - Assembly Language',0
tableProp_date		DC.B	'April 20, 2012',0

discard_text1		DC.B	' Select up to 3 cards to discard ',0
discard_text2		DC.B	' or Stand Pat. ',0
discard_button_text_0	DC.B	'Stand Pat',0
discard_button_text_1	DC.B	' Discard ',0
gameover_text		DC.B	' Game Over. Thanks for playing! ',0

winning_text8		DC.B	'    Straight Flush   ',0
winning_text7		DC.B	'     4 of a Kind     ',0
winning_text6		DC.B	'      Full House     ',0
winning_text5		DC.B	'        Flush        ',0
winning_text4		DC.B	'       Straight      ',0
winning_text3		DC.B	'     3 of a Kind     ',0
winning_text2		DC.B	'       Two Pair      ',0
winning_text1		DC.B	'       One Pair      ',0

winning_text0_14	DC.B	'       Ace High      ',0
winning_text0_13	DC.B	'       King High     ',0
winning_text0_12	DC.B	'      Queen High     ',0
winning_text0_11	DC.B	'       Jack High     ',0
winning_text0_10	DC.B	'        10 High      ',0
winning_text0_9		DC.B	'         9 High      ',0
winning_text0_8		DC.B	'         8 High      ',0
winning_text0_7		DC.B	'         7 High      ',0

playerHand	DS.B	5			; 5 cards
dealerHand	DS.B	5

playerScore	DC.B	0
dealerScore	DC.B	0

playerScoreCards DC.L	0
dealerScoreCards DC.L	0

playerWins	DC.B	0
dealerWins	DC.B	0

discardArray	DS.B	5
discardCount	DC.B	0

playerWinText	DC.B	' Player Wins!!! :) ',0
dealerWinText	DC.B	' Dealer Wins... :( ',0
drawWinText	DC.B	' It''s a draw! -.- ',0

var_playerSwapText DC.B	'Player discarded: 0',0
var_dealerSwapText DC.B	'Dealer discarded: 0',0

var_gameMode	DS.B	1

var_testModeText DC.B	'* Test Mode *',0
testModeDetails	DC.B	'* Test Mode *',$0D,$0A,$0D,$0A
		DC.B	'Card Numbers:',$0D,$0A
		DC.B	'ex. 143 = Ace of Hearts',$0D,$0A
		DC.B	'ex. 61 = Six of Clubs',$0D,$0A,$0D,$0A
		DC.B	'14x - Ace              1 - Clubs',$0D,$0A
		DC.B	'13x - King             2 - Diamonds',$0D,$0A
		DC.B	'12x - Queen            3 - Hearts',$0D,$0A
		DC.B	'11x - Jack             4 - Spades',$0D,$0A
		DC.B	'10x - Ten',$0D,$0A
		DC.B	' 9x - Nine',$0D,$0A
		DC.B	' 8x - Eight',$0D,$0A
		DC.B	' 7x - Seven',$0D,$0A
		DC.B	' 6x - Six',$0D,$0A
		DC.B	' 5x - Five',$0D,$0A
		DC.B	' 4x - Four',$0D,$0A
		DC.B	' 3x - Three',$0D,$0A
		DC.B	' 2x - Two',$0D,$0A,$0D,$0A,0

promptPlayer	DC.B	'Enter card number for player hand: ',0
promptDealer	DC.B	'Enter card number for dealer hand: ',0

*deck of cards
* card = card * 10 + suit
* suits:
*  1 = Clubs
*  2 = Diamonds
*  3 = Hearts
*  4 = Spades					; Array Index
deck		DC.B	144			; 0
		DC.B	143			; 1
		DC.B	142			; 2
		DC.B	141			; 3
		DC.B	134			; 4
		DC.B	133			; 5
		DC.B	132			; 6
		DC.B	131			; 7
		DC.B	124			; 8
		DC.B	123			; 9
		DC.B	122			; 10
		DC.B	121			; 11
		DC.B	114			; 12
		DC.B	113			; 13
		DC.B	112			; 14
		DC.B	111			; 15
		DC.B	104			; 16
		DC.B	103			; 17
		DC.B	102			; 18
		DC.B	101			; 19
		DC.B	94			; 20
		DC.B	93			; 21
		DC.B	92			; 22
		DC.B	91			; 23
		DC.B	84			; 24
		DC.B	83			; 25
		DC.B	82			; 26
		DC.B	81			; 27
		DC.B	74			; 28
		DC.B	73			; 29
		DC.B	72			; 30
		DC.B	71			; 31
		DC.B	64			; 32
		DC.B	63			; 33
		DC.B	62			; 34
		DC.B	61			; 35
		DC.B	54			; 36
		DC.B	53			; 37
		DC.B	52			; 38
		DC.B	51			; 39
		DC.B	44			; 40
		DC.B	43			; 41
		DC.B	42			; 42
		DC.B	41			; 43
		DC.B	34			; 44
		DC.B	33			; 45
		DC.B	32			; 45
		DC.B	31			; 47
		DC.B	24			; 48
		DC.B	23			; 49
		DC.B	22			; 50
		DC.B	21			; 51

*rectangle coordinates
RX		DS.W	1
RY		DS.W	1
RW		DS.W	1
RH		DS.W	1
*temp variables
tempX		DS.W	1
tempY		DS.W	1
tempCard	DS.W	1
tempCardString	DC.B	'  ',0



	END	START

































*~Font name~Courier New~
*~Font size~10~
*~Tab type~1~
*~Tab size~8~
